# chrono - agendas system
# Copyright (C) 2022  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.forms import ValidationError
from django.template import Template, TemplateSyntaxError
from django.utils.translation import ugettext_lazy as _

from chrono.pricing.models import Criteria


class NewCriteriaForm(forms.ModelForm):
    class Meta:
        model = Criteria
        fields = ['label', 'condition']

    def clean_condition(self):
        condition = self.cleaned_data['condition']
        try:
            Template('{%% if %s %%}OK{%% endif %%}' % condition)
        except TemplateSyntaxError:
            raise ValidationError(_('Invalid syntax.'))

        return condition


class CriteriaForm(NewCriteriaForm):
    class Meta:
        model = Criteria
        fields = ['label', 'slug', 'condition']

    def clean_slug(self):
        slug = self.cleaned_data['slug']

        if self.instance.category.criterias.filter(slug=slug).exclude(pk=self.instance.pk).exists():
            raise ValidationError(_('Another criteria exists with the same identifier.'))

        return slug
